@@ -9,7 +9,7 @@ Captive::Portal::Role::Utils - common utils for Captive::Portal
 
 =cut
 
-our $VERSION = '2.11';
+our $VERSION = '2.12';
 
 use Log::Log4perl qw(:easy);
 use Capture::Tiny qw(capture);
@@ -197,111 +197,6 @@ sub drop_privileges {
 
 }
 
-=item $capo->gettext($msg_nr)
-
-Poor mans gettext. Returns language specific text from config hash for message number.
-
-=cut
-
-sub gettext {
-    my $self = shift;
-    my $text = shift
-      or LOGDIE 'missing param text';
-
-    my $i18n_text =
-      $self->cfg->{I18N_MSG_CATALOG}{$text}{ $self->{CTX}{LANG} };
-
-    unless ($i18n_text) {
-        ERROR "missing I18N text for '$text' in lang: $self->{CTX}{LANG}";
-        $i18n_text = "missing '$text' for lang '$self->{CTX}{LANG}'";
-    }
-
-    return $i18n_text;
-}
-
-=item $capo->choose_language()
-
-Parses the HTTP header 'Accept-Language' and returns an appropriate language from the configured languages or the fallback language.
-
-=cut
-
-sub choose_language {
-    my $self  = shift;
-    my $query = $self->{CTX}{QUERY};
-
-    my $http_accept_language = $query->http('HTTP_ACCEPT_LANGUAGE')
-      || '';
-    DEBUG("HTTP-Accept-Language is: $http_accept_language");
-
-    ###
-    # parse the HTTP header
-    #
-    # Example header: de-de,de;q=0.8,en-us;q=0.5,en;q=0.3
-    #
-    my $default_quant = 1;
-    my %languages;
-
-    foreach my $item ( split( /,/, $http_accept_language ) ) {
-        $item =~ s/\s//g;    #strip spaces
-
-        my ( $lang, $quant ) = split( /;q=/, $item );
-
-        # don't use fine-granular language subtags for CaPo
-        # cutoff the language subtags: de-AT => de
-        $lang =~ s/-.*//;
-
-        # skip silently the wildcard '*'
-        next if $lang eq '*';
-
-        # parse error, silently skip this language item
-        next if defined $quant && ( not looks_like_number($quant) );
-
-        # set the default language quantifier
-        unless ( defined $quant ) {
-
-            # give the first one a quant of 1
-            $quant = $default_quant;
-
-            # and the next without quantification .001 less
-            $default_quant -= 0.001;
-        }
-
-        # first language entry
-        unless ( $languages{$lang} ) {
-            $languages{$lang} = $quant;
-            next;
-        }
-
-        # override language entry with higher quant
-        if ( $quant > $languages{$lang} ) {
-            $languages{$lang} = $quant;
-            next;
-        }
-
-    }
-
-    # sort in descending quantification order
-    my @accept_languages_sorted =
-      sort { $languages{$b} <=> $languages{$a} } keys %languages;
-
-    DEBUG( 'language prefered order is: '
-          . join( ' > ', @accept_languages_sorted ) );
-
-    DEBUG( 'configured languages: '
-          . join( ' ', @{ $self->cfg->{I18N_LANGUAGES} } ) );
-
-    # look for accepted language in configured languages
-    my $choosen_language;
-    foreach my $lang (@accept_languages_sorted) {
-        if ( grep m/\A\Q$lang\E\Z/, @{ $self->cfg->{I18N_LANGUAGES} } ) {
-            $choosen_language = $lang;
-            last;    # ready
-        }
-    }
-
-    return $choosen_language || $self->cfg->{I18N_FALLBACK_LANG};
-}
-
 =item $capo->run_cmd(@cmd_with_options, [$run_cmd_options])
 
 Wrapper to run external commands, capture and return (stdout/stderr).
@@ -484,9 +379,6 @@ Foundation; either version 2, or (at your option) any later version, or
 
 b) the Artistic License version 2.0.
 
-The full text of the license can be found in the LICENSE file included
-with this distribution.
-
 =cut
 
 # vim: sw=4
